<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\About;
use Illuminate\Http\Request;

class AboutController extends Controller
{
    private $image_dir = 'images/about';
    
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $about = About::get();
        return view('admin.about.index', compact('about'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.about.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required|string',
            'short_description' => 'required|string'

        ]);

        $about = new About();
        $image = $request->file('image');
        $fileName = $this->image_dir . '/' . 'about_' . date('dmyHis') . '.' . $image->getClientOriginalExtension();
        $destinationPath = public_path($this->image_dir);
        $image->move($destinationPath, $fileName);

        $about->image = $fileName;
        $about->title = $request->title;
        $about->short_description = $request->short_description;
        $about->description = $request->description;

        $about->save();
        return redirect()->route('about.index')->with('success', 'About content has been created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\About  $about
     * @return \Illuminate\Http\Response
     */
    public function show(About $about)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\About  $about
     * @return \Illuminate\Http\Response
     */
    public function edit(About $about)
    {
        return view('admin.about.edit', compact('about'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\About  $about
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, About $about)
    {
        $this->validate($request, [
            'title' => 'required|string',
            'short_description' => 'required|string'

        ]);
        if (!empty($request->file('image'))) {
            $image = $request->file('image');
            $fileName = $this->image_dir . '/' . 'about_' . date('dmyHis') . '.' . $image->getClientOriginalExtension();
            $destinationPath = public_path($this->image_dir);
            $image->move($destinationPath, $fileName);

            $about->image = $fileName;
        }
        $about->title = $request->title;
        $about->short_description = $request->short_description;
        $about->description = $request->description;
        $about->status = !empty($request->status) ? $request->status : 1;
        $about->save();
        return redirect()->route('about.index')->with('success', 'About content has been created successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\About  $about
     * @return \Illuminate\Http\Response
     */
    public function destroy(About $about)
    {
        $about->delete();
        return redirect()->route('about.index')->with('success', 'About content has been deleted successfully');
    }
}
