<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Brand;
use Carbon\Carbon;
use Illuminate\Http\Request;

class BrandController extends Controller
{
    private $image_dir = 'images/brands';
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $brand = Brand::get();
        return view('admin.brands.index', compact('brand'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.brands.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'brand_name' => 'required|string'
        ]);

        $brand = new Brand();
        $image = $request->file('logo');
        $fileName = $this->image_dir . '/' . 'brand_' . date('dmyHis') . '.' . $image->getClientOriginalExtension();
        $destinationPath = public_path($this->image_dir);
        $image->move($destinationPath, $fileName);

        $brand->logo = $fileName;
        // if (!empty($request->file('logo'))) {
        //     $filename = 'brand_' . date('dmyHis') . '.' . $request->logo->getClientOriginalExtension();
        //     $brand->logo =  $this->fileupload($this->image_dir, $request->logo, $filename);
        // }
        $brand->brand_name = $request->brand_name;
        if ($brand->save()) {
            $lastId = $brand->id;
            Brand::where('status', true)->where('id', '!=', $lastId)->update(['status' => false, 'deleted_at' => Carbon::now()]);
        }
        return redirect()->route('brands.index')->with('success', 'Brand has been created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Brand  $brand
     * @return \Illuminate\Http\Response
     */
    public function show(Brand $brand)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Brand  $brand
     * @return \Illuminate\Http\Response
     */
    public function edit(Brand $brand)
    {
        return view('admin.brands.edit', compact('brand'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Brand  $brand
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Brand $brand)
    {
        $this->validate($request, [
            'brand_name' => 'required|string'
        ]);
        if (!empty($request->file('logo'))) {
            $image = $request->file('logo');
            $fileName = $this->image_dir . '/' . 'brand_' . date('dmyHis') . '.' . $image->getClientOriginalExtension();
            $destinationPath = public_path($this->image_dir);
            $image->move($destinationPath, $fileName);

            $brand->logo = $fileName;
            // $logo               = $request->file('logo');
            // $logo               = $request->logo->store($this->image_dir, ['disk' => 'public']);
            // $brand->logo     = $logo;
        }
        $brand->brand_name = $request->brand_name;
        $brand->status = !empty($request->status) ? $request->status : 1;
        $brand->save();
        return redirect()->route('brands.index')->with('success', 'Brand has been updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Brand  $brand
     * @return \Illuminate\Http\Response
     */
    public function destroy(Brand $brand)
    {
        $brand->delete();
        return redirect()->route('brands.index')->with('success', 'Brand has been deleted successfully');
    }
}
