<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\HomeContent;
use Carbon\Carbon;
use Illuminate\Http\Request;

class HomeContentController extends Controller
{
    private $image_dir = 'images/homebanners';

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $homecontent = HomeContent::get();
        return view('admin.home-content.index', compact('homecontent'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.home-content.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required|string'
        ]);

        $homecontent = new HomeContent();
        $image = $request->file('banner');
        $fileName = $this->image_dir . '/' . 'homebanner_' . date('dmyHis') . '.' . $image->getClientOriginalExtension();
        $destinationPath = public_path($this->image_dir);
        $image->move($destinationPath, $fileName);

        $homecontent->banner = $fileName;
        $homecontent->title = $request->title;
        $homecontent->short_description = $request->short_description;
        if ($homecontent->save()) {
            $lastId = $homecontent->id;
            HomeContent::where('status', true)->where('id', '!=', $lastId)->update(['status' => false, 'deleted_at' => Carbon::now()]);
        }
        return redirect()->route('home-content.index')->with('success', 'Home Content has been created successfully.');
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Models\HomeContent  $homeContent
     * @return \Illuminate\Http\Response
     */
    public function show(HomeContent $homeContent)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\HomeContent  $homeContent
     * @return \Illuminate\Http\Response
     */
    public function edit(HomeContent $homeContent)
    {
        return view('admin.home-content.edit', compact('homeContent'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\HomeContent  $homeContent
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, HomeContent $homeContent)
    {
        $this->validate($request, [
            'title' => 'required|string'
        ]);
        if (!empty($request->file('banner'))) {
            $image = $request->file('banner');
            $fileName = $this->image_dir . '/' . 'homebanner_' . date('dmyHis') . '.' . $image->getClientOriginalExtension();
            $destinationPath = public_path($this->image_dir);
            $image->move($destinationPath, $fileName);

            $homeContent->banner = $fileName;
        }
        $homeContent->title = $request->title;
        $homeContent->short_description = $request->short_description;
        $homeContent->status = !empty($request->status) ? $request->status : 1;
        $homeContent->save();
        return redirect()->route('home-content.index')->with('success', 'Home Content has been updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\HomeContent  $homeContent
     * @return \Illuminate\Http\Response
     */
    public function destroy(HomeContent $homeContent)
    {
        $homeContent->delete();
        return redirect()->route('home-content.index')->with('success', 'Home Content has been deleted successfully');
    }
}
