<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Product;
use App\Models\ProductCategory;
use App\Models\ProductImage;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class ProductController extends Controller
{
    private $documents = 'documents/products';
    private $image_dir = 'images/products';
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $products = Product::get();
        return view('admin.products.index', compact('products'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $category = ProductCategory::get();
        return view('admin.products.create', compact('category'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $this->validate($request, [
            'product_name' => 'required|string',
            'category' => 'required|string',
            'price' => 'required|string'
        ]);

        $product = new Product();


        if (!empty($request->file('document'))) {
            $filename = 'product_' . date('dmyHis') . '.' . $request->document->getClientOriginalExtension();
            $product->document =  $this->fileupload($this->documents, $request->document, $filename);
        }

        $product->product_name = $request->product_name;
        $product->slug = $request->slug;
        $product->slug = Str::slug($request->product_name);
        $product->category = $request->category;
        $product->price = $request->price;
        $product->video_url = $request->video_url;
        $product->short_description = $request->short_description;
        $product->description = $request->description;
        $product->save();
        if ($product->save()) {
            if (!is_null(request('thumnail'))) {
                $uploadcount = 0;
                foreach ($request->thumnail as $photo) {
                    $product_image = new ProductImage();
                    $product_image->product_id = $product->id;
                    // $image = $request->file('thumnail');
                    $fileName = $this->image_dir . '/' . 'product_image_' . date('dmyHis') . '.' . $photo->getClientOriginalName();
                    $destinationPath = public_path($this->image_dir);
                    $photo->move($destinationPath, $fileName);

                    $product_image->thumnail = $fileName;
                    // $filename =  $photo->getClientOriginalName();
                    // $photo->move($this->image_dir, $filename);
                    // $product_image->thumnail =  $this->fileupload($this->image_dir, $photo, $filename);
                    $product_image->save();
                    $uploadcount++;
                }
            }
        }
        return redirect()->route('products.index')->with('success', 'Product has been created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function show(Product $product)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function edit(Product $product)
    {
        // $product_images = Product::find(1)->ProductImagesByID;
        $category = ProductCategory::get();
        return view('admin.products.edit', compact('product', 'category'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Product $product, ProductImage $product_image)
    {
        $this->validate($request, [
            'product_name' => 'required|string',
            'category' => 'required|string',
            'price' => 'required|string'
        ]);

        if (!empty($request->file('document'))) {
            $filename = 'product_' . date('dmyHis') . '.' . $request->document->getClientOriginalExtension();
            $product->document =  $this->fileupload($this->documents, $request->document, $filename);
        }

        $product->product_name = $request->product_name;
        $product->slug = $request->slug;
        $product->slug = Str::slug($request->product_name);
        $product->category = $request->category;
        $product->price = $request->price;
        $product->video_url = $request->video_url;
        $product->status = !empty($request->status) ? $request->status : 1;
        $product->short_description = $request->short_description;
        $product->description = $request->description;
        $product->save();
        if ($product->save()) {
            if (!is_null(request('thumnail'))) {
                $product->ProductImagesByID()->delete();
                $uploadcount = 0;
                foreach ($request->thumnail as $photo) {
                    $product_image = new ProductImage();
                    $product_image->product_id = $product->id;
                    // $filename =  $photo->getClientOriginalName();
                    $fileName = $this->image_dir . '/' . 'product_image_' . date('dmyHis') . '.' . $photo->getClientOriginalName();
                    $destinationPath = public_path($this->image_dir);
                    $photo->move($destinationPath, $fileName);

                    $product_image->thumnail = $fileName;
                    // $photo->move($this->image_dir, $filename);
                    // $product_image->thumnail =  $this->fileupload($this->image_dir, $photo, $filename);
                    $product_image->save();
                    $uploadcount++;
                }
            }
        }
        // if ($request->hasFile('thumnail')) {
        //     $product->ProductImagesByID()->delete();
        //     $uploadcount = 0;
        //     foreach ($request->thumnail as $photo) {
        //         $product_image->product_id = $product->id;
        //         $filename =  $photo->getClientOriginalName();
        //         $product_image->thumnail =  $this->fileupload($this->image_dir, $photo, $filename);
        //         $product_image->save();
        //         $uploadcount++;
        //     }
        // }
        return redirect()->route('products.index')->with('success', 'Product has been updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function destroy(Product $product)
    {
        $product->ProductImagesByID()->delete();
        $product->delete();

        return redirect()->route('products.index')->with('success', 'Product has been deleted successfully');
    }
}
