<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\WebsiteDetail;
use Carbon\Carbon;
use Illuminate\Http\Request;

class WebsiteDetailController extends Controller
{
    private $image_dir = 'images/sitedetail';

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $siteDetail = WebsiteDetail::get();
        return view('admin.website-detail.index', compact('siteDetail'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.website-detail.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'company_name' => 'required|string'
        ]);

        $siteDetail = new WebsiteDetail();

        if (!empty($request->file('logo'))) {
            $image = $request->file('logo');
            $fileName = $this->image_dir . '/' . 'website_detail_' . date('dmyHis') . '.' . $image->getClientOriginalExtension();
            $destinationPath = public_path($this->image_dir);
            $image->move($destinationPath, $fileName);

            $siteDetail->logo = $fileName;
            // $filename = 'siteDetail_' . date('dmyHis') . '.' . $request->logo->getClientOriginalExtension();
            // $siteDetail->logo =  $this->fileupload($this->image_dir, $request->logo, $filename);
        }
        $siteDetail->company_name = $request->company_name;
        $siteDetail->email = $request->email;
        $siteDetail->phone = $request->phone;
        $siteDetail->facebook_url = $request->facebook_url;
        $siteDetail->instagram_url = $request->instagram_url;
        $siteDetail->twitter_url = $request->twitter_url;
        $siteDetail->linkedin_url = $request->linkedin_url;
        $siteDetail->address = $request->address;
        $siteDetail->description = $request->description;
        if ($siteDetail->save()) {
            $lastId = $siteDetail->id;
            WebsiteDetail::where('status', true)->where('id', '!=', $lastId)->update(['status' => false, 'deleted_at' => Carbon::now()]);
        }
        return redirect()->route('website-detail.index')->with('success', 'Basic Detail has been created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\WebsiteDetail  $website_detail
     * @return \Illuminate\Http\Response
     */
    public function show(WebsiteDetail $website_detail)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\WebsiteDetail  $website_detail
     * @return \Illuminate\Http\Response
     */
    public function edit(WebsiteDetail $website_detail)
    {
        return view('admin.website-detail.edit', compact('website_detail'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\WebsiteDetail  $website_detail
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, WebsiteDetail $website_detail)
    {
        $this->validate($request, [
            'company_name' => 'required|string',
            'phone' => 'required|integer'
        ]);
        if (!empty($request->file('logo'))) {
            // $logo               = $request->file('logo');
            // $logo               = $request->logo->store($this->image_dir, ['disk' => 'public']);
            // $website_detail->logo     = $logo;
            $image = $request->file('logo');
            $fileName = $this->image_dir . '/' . 'website_detail_' . date('dmyHis') . '.' . $image->getClientOriginalExtension();
            $destinationPath = public_path($this->image_dir);
            $image->move($destinationPath, $fileName);

            $website_detail->logo = $fileName;
        }
        $website_detail->company_name = $request->company_name;
        $website_detail->email = $request->email;
        $website_detail->phone = $request->phone;
        $website_detail->facebook_url = $request->facebook_url;
        $website_detail->instagram_url = $request->instagram_url;
        $website_detail->twitter_url = $request->twitter_url;
        $website_detail->linkedin_url = $request->linkedin_url;
        $website_detail->address = $request->address;
        $website_detail->description = $request->description;
        $website_detail->status = !empty($request->status) ? $request->status : 1;
        $website_detail->save();
        return redirect()->route('website-detail.index')->with('success', 'Basic Detail has been updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\WebsiteDetail  $website_detail
     * @return \Illuminate\Http\Response
     */
    public function destroy(WebsiteDetail $website_detail)
    {
        $website_detail->delete();
        return redirect()->route('website-detail.index')->with('success', 'Basic Detail has been deleted successfully');
    }
}
